"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const prompts_1 = require("@clack/prompts");
const execa_1 = __importDefault(require("execa"));
const picocolors_1 = __importDefault(require("picocolors"));
const integration_1 = require("../../domains/create/integration");
const utils_1 = require("../../utils");
const helpers_1 = require("../../domains/create/integration/helpers");
class GenerateSDK extends core_1.Command {
    async run() {
        let projectDir = "";
        let framework = "";
        const sp = (0, prompts_1.spinner)();
        const { flags } = await this.parse(GenerateSDK);
        if (flags.framework) {
            framework = flags.framework;
        }
        const { args } = await this.parse(GenerateSDK);
        // eslint-disable-next-line dot-notation
        if (args["name"]) {
            // eslint-disable-next-line dot-notation
            projectDir = args["name"];
        }
        // greet the user
        (0, prompts_1.intro)("Welcome to Vue Storefront SDK Integration Boilerplate Generator!");
        projectDir = await (0, helpers_1.handleDirectoryName)(projectDir);
        framework = await (0, helpers_1.handleFrameworkName)(framework);
        const packageManager = await (0, utils_1.getPkgManager)();
        await (0, integration_1.createIntegrationBoilerplate)({ projectDir, framework });
        await (0, helpers_1.installAppSdkDependencies)(projectDir, packageManager);
        // build the boilerplate
        sp.start("Building the boilerplate");
        const cliDir = `${projectDir}/cli`;
        await (0, execa_1.default)(packageManager, ["run", "build"], { cwd: projectDir });
        await (0, execa_1.default)(packageManager, ["run", "build"], { cwd: cliDir });
        sp.stop("Boilerplate has been built successfully!");
        // clean up the git repository
        await (0, helpers_1.cleanUpRepositories)(projectDir);
        // exit the generator
        (0, utils_1.log)("SDK integration boilerplate has been generated successfully!");
        (0, utils_1.log)("To start the development, run the following commands:");
        (0, utils_1.log)(picocolors_1.default.green(`cd ${projectDir}`));
        (0, utils_1.log)(picocolors_1.default.green(`${packageManager === "yarn" ? "yarn dev" : "npm run dev"}`));
        process.exit(0);
    }
}
exports.default = GenerateSDK;
GenerateSDK.description = "Generate integration boilerplate";
GenerateSDK.examples = ["<%= config.bin %> <%= command.id %>"];
GenerateSDK.flags = {
    framework: core_1.Flags.string({
        char: "t",
        description: "Framework to use",
        options: ["nuxt", "next"],
        aliases: ["template"],
    }),
};
GenerateSDK.args = [
    {
        name: "name",
    },
];
