"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getPkgManager = void 0;
const prompts_1 = require("@clack/prompts");
const execa_1 = __importDefault(require("execa"));
const _1 = require(".");
const checkPackageManager = async (packageManager) => {
    try {
        await (0, execa_1.default)(packageManager, ["--version"], { stdio: "ignore" });
    }
    catch {
        return false;
    }
    return true;
};
const getPkgManager = async (pkgManager) => {
    let packageManager = pkgManager || "yarn";
    packageManager = (await (0, prompts_1.select)({
        message: "What package manager do you want to use?",
        options: [
            { label: "NPM", value: "npm" },
            { label: "Yarn", value: "yarn" },
        ],
    }));
    const isPackageManagerExists = await checkPackageManager(packageManager);
    if (!isPackageManagerExists) {
        const useAnotherPackageManager = await (0, prompts_1.confirm)({
            message: `Package manager ${packageManager} not found. Do you want to use another package manager?`,
            active: "Yes",
        });
        if (useAnotherPackageManager) {
            if (packageManager === "npm") {
                packageManager = "yarn";
            }
            else {
                packageManager = "npm";
            }
            return await (0, exports.getPkgManager)(packageManager);
        }
        (0, _1.log)("Please install package manager and try again.");
        process.exit(1);
    }
    return packageManager;
};
exports.getPkgManager = getPkgManager;
